package com.docus.bgts.config;

import com.alibaba.druid.pool.DruidDataSource;
import org.apache.ibatis.session.SqlSessionFactory;
import org.mybatis.spring.SqlSessionFactoryBean;
import org.mybatis.spring.annotation.MapperScan;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.core.io.support.PathMatchingResourcePatternResolver;
import org.springframework.jdbc.datasource.DataSourceTransactionManager;

import javax.sql.DataSource;

@Configuration
@MapperScan(basePackages = DbOracleConfig.PACKAGE, sqlSessionFactoryRef = "dboracleSqlSessionFactory")
public class DbOracleConfig {
    // 这里一定要指定精准  否则后果不堪设想
    static final String PACKAGE = "com.docus.bgts.mapper.dboracle";
    static final String MAPPER_LOCATION = "classpath:mapper/dboracle/*.xml";

    @Bean(name = "dboracleDataSource")
    @ConfigurationProperties(prefix = "spring.datasource.oracle-docus")
    public DataSource secondDataSource(){
        return new DruidDataSource();
    }

    /*注入事务*/
    @Bean(name = "dboracleTransactionManager")
    public DataSourceTransactionManager secondTransactionManager() {
        return new DataSourceTransactionManager(secondDataSource());
    }

    @Bean(name = "dboracleSqlSessionFactory")
    public SqlSessionFactory secondSqlSessionFactory(@Qualifier("dboracleDataSource") DataSource secondDataSource)
            throws Exception {
        final SqlSessionFactoryBean sessionFactory = new SqlSessionFactoryBean();
        sessionFactory.setDataSource(secondDataSource);
        sessionFactory.setMapperLocations(new PathMatchingResourcePatternResolver()
                .getResources(DbOracleConfig.MAPPER_LOCATION));
        return sessionFactory.getObject();
    }

}
