package com.docus.bgts.controller;

import com.docus.bgts.entity.CommonResult;
import com.docus.bgts.facade.IAfCollectTaskService;
import com.docus.bgts.facade.IBgtsService;
import com.docus.bgts.service.CheckIntegrityService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

/**
 * @author YongBin Wen
 * @date 2024/1/11 9:42
 */
@Api(value = "封存病案报告采集接口", tags = "封存病案报告采集接口")
@RestController
@RequestMapping("/seal/collect")
@Slf4j
public class SealReportCollectController {
    @Autowired
    CheckIntegrityService checkIntegrityService;

    @Autowired
    IBgtsService bgtsService;

    @Autowired
    IAfCollectTaskService afCollectTaskService;

    @ApiOperation("封存病案Pacs采集接口")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "sealId", value = "t_seal 的seal_id,封存id", required = true, dataTypeClass = String.class)
    })
    @GetMapping("/pacs")
    public CommonResult<String> collectSealPacs(@RequestParam("sealId") String sealId) {
        log.info("封存病案采集pacs病历,封存id为：{}", sealId);
        try {
            bgtsService.collectSealPacs(sealId);
            log.info("封存病案采集pacs病历,封存id:{} 采集完成", sealId);
            return CommonResult.success("采集完成");
        } catch (Exception e) {
            log.error("封存id：" + sealId + " 封存病案采集pacs病历，出现异常！", e);
            return CommonResult.failed(e.getMessage());
        }
    }


    @ApiOperation("心电采集接口")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "sealId", value = "t_seal 的seal_id,封存id", required = true, dataTypeClass = String.class)
    })
    @GetMapping("/ecg")
    public CommonResult<String> collectSealEcg(@RequestParam("sealId") String sealId) {
        log.info("封存病案采集 心电图 病历,封存id为：{}", sealId);
        try {
            bgtsService.collectSealEcg(sealId);
            log.info("封存病案采集 心电图 病历,封存id:{} 采集完成", sealId);
            return CommonResult.success("采集完成");
        } catch (Exception e) {
            log.error("封存id：" + sealId + " 封存病案采集 心电图 病历，出现异常！", e);
            return CommonResult.failed(e.getMessage());
        }
    }

    @ApiOperation("内镜采集接口")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "sealId", value = "t_seal 的seal_id,封存id", required = true, dataTypeClass = String.class)
    })
    @GetMapping("/endoscopy")
    public CommonResult<String> collectSealEndoscopy(@RequestParam("sealId") String sealId) {
        log.info("封存病案采集 内镜 病历,封存id为：{}", sealId);
        try {
            bgtsService.collectSealEndoscopy(sealId);
            log.info("封存病案采集 内镜 病历,封存id:{} 采集完成", sealId);
            return CommonResult.success("采集完成");
        } catch (Exception e) {
            log.error("封存id：" + sealId + " 封存病案采集 内镜 病历，出现异常！", e);
            return CommonResult.failed(e.getMessage());
        }
    }


    @ApiOperation("重症采集接口")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "sealId", value = "t_seal 的seal_id,封存id", required = true, dataTypeClass = String.class)
    })
    @GetMapping("/icu")
    public CommonResult<String> collectSealIcu(@RequestParam("sealId") String sealId) {
        log.info("封存病案采集 重症 病历,封存id为：{}", sealId);
        try {
            bgtsService.collectSealIcu(sealId);
            log.info("封存病案采集 重症 病历,封存id:{} 采集完成", sealId);
            return CommonResult.success("采集完成");
        } catch (Exception e) {
            log.error("封存id：" + sealId + " 封存病案采集 重症 病历，出现异常！", e);
            return CommonResult.failed(e.getMessage());
        }
    }


    @ApiOperation("手麻采集接口")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "sealId", value = "t_seal 的seal_id,封存id", required = true, dataTypeClass = String.class)
    })
    @GetMapping("/surgicalAnesthesia")
    public CommonResult<String> collectSealSurgicalAnesthesia(@RequestParam("sealId") String sealId) {
        log.info("封存病案采集 手麻 病历,封存id为：{}", sealId);
        try {
            bgtsService.collectSealSurgicalAnesthesia(sealId);
            log.info("封存病案采集 手麻 病历,封存id:{} 采集完成", sealId);
            return CommonResult.success("采集完成");
        } catch (Exception e) {
            log.error("封存id：" + sealId + " 封存病案采集 手麻 病历，出现异常！", e);
            return CommonResult.failed(e.getMessage());
        }
    }


}
