package com.docus.bgts.facade;


import com.baomidou.mybatisplus.extension.service.IService;
import com.docus.bgts.entity.AfCollectTask;
import com.docus.bgts.entity.TBasic;
import com.docus.bgts.entity.TSeal;
import com.docus.bgts.rpc.dto.ReportDownDto;

import java.util.List;
import java.util.Map;

/**
 * <p>
 * 病案采集任务 服务类
 * </p>
 *
 * @author 曾文和
 * @since 2021-05-07
 */
public interface IAfCollectTaskService extends IService<AfCollectTask> {
    /**
     * 获取病案id通过报告唯一单号
     */
    String getpatientIdByEmpId(String empId);

    void insert(ReportDownDto reportDownDto);

    String getJzhByInpatientNo(String inPatientNo,String visitId);
    /**
     * 查询数据库是否存在该jzh患者
     */
    String getJzhByJzh(String jzh);

    void insertServer(ReportDownDto reportDownDto);

    void updateInterfaceCollect(String collectSubId, int state);

    /**
     * 通过出院日期获取患者jzh
     * @param startDate 开始日期
     * @param endDate   结束日期
     * @return
     */
    List<Map> getjzhByDate(String startDate,String endDate,int size,int current);

    /**
     * 通过记帐号获取唯一报告单号
     * @param patientIds
     * @return
     */
    List<String> getC1ByPatientId(List<String> patientIds,String collectorId);

    /**
     * 通过唯一报告单号获取patient_id
     * @param C1s
     * @return
     */
    List<String> getPatientIdByC1(List<String> C1s);

    /**
     * 通过记帐号获取jzh
     * @param patientIds
     * @return
     */
    List<String> getJzhByPatientId(List<String> patientIds);

    /**
     * 通过住院号和住院次数获取patient_id
     */

    String getPatientIdByInpatientNo(String inPatientNo,String visitId);

    /**
     * 根据jzh集合查询文件采集任务情况
     * @param jzhs
     * @return
     */
    List<Map> getCompleteIntegrity(List<String> jzhs);


    /**
     * 根据封存条件查询封存信息
     *
     * @param seal 封存条件
     * @return com.docus.server.collect.entity.TSeal
     * @date 2024/1/10 16:52
     * @author YongBin Wen
     */
    TSeal findSealByCondition(TSeal seal);

    /**
     * 根据患者信息获取基础病案信息 from    `docus_medicalrecord`.`t_basic`
     *
     * @param tBasic 患者基础信息
     * @return 病案基础信息
     */
    List<TBasic> getBasicInfo(TBasic tBasic);
}
