package com.docus.bgts.mapper.dbmysql;


import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.docus.bgts.entity.AfCollectTask;
import com.docus.bgts.entity.JzhListSync;
import com.docus.bgts.entity.TBasic;
import com.docus.bgts.entity.TSeal;
import org.apache.ibatis.annotations.Param;
import org.springframework.web.bind.annotation.RequestParam;

import java.util.List;
import java.util.Map;

/**
 * <p>
 * 病案采集任务 Mapper 接口
 * </p>
 *
 * @author 曾文和
 * @since 2021-05-07
 */
public interface AfCollectTaskMapper extends BaseMapper<AfCollectTask> {
    /**
     * 获取病案id通过报告唯一单号
     * @param empId
     * @return
     */
    String getpatientIdByEmpId(@Param("jzh") String empId);

    String getPatientIdByInpatientNo(@Param("inPatientNo") String inPatientNo,@Param("visitId") String visitId);

    String getJzhByInpatientNo(@Param("inPatientNo") String inPatientNo,@Param("visitId") String visitId);

    String getJzhByJzh(@Param("jzh") String jzh);
    /**
     * 通过出院日期获取患者jzh
     * @param startDate 开始日期
     * @param endDate   结束日期
     * @return
     */
    List<Map> getjzhByDate(@Param("startDate") String startDate, @Param("endDate") String endDate, @RequestParam("size") int size, @RequestParam("current") int current);

    /**
     * 通过记帐号与采集器编号获取唯一报告单号
     * @param patientIds 记帐号集合
     * @param collectorId 采集器编号
     * @return
     */
    List<String> getC1ByPatientId(@Param("patientIds") List<String> patientIds,@Param("collectorId") String collectorId);

    /**
     * 通过唯一报告单号获取patient_id
     * @param C1s
     * @return
     */
    List<String> getPatientIdByC1(@Param("C1s") List<String> C1s);
    /**
     * 通过记帐号获取jzh
     * @param patientIds 记帐号集合
     * @return
     */
    List<String> getJzhByPatientId(@Param("patientIds") List<String> patientIds);

    /**
     * 根据记帐号分组查询完成情况
     * @param jzhs
     * @return
     */
    List<JzhListSync> selectListByJzhs(@Param("jzhs") List<String> jzhs);

    /**
     * 根据封存条件查询封存信息
     *
     * @param seal 封存条件
     * @return com.docus.server.collect.entity.TSeal
     * @date 2024/1/10 16:52
     * @author YongBin Wen
     */
    TSeal findSealByCondition(@Param("seal") TSeal seal);

    /**
     * 根据患者信息获取基础病案信息 from    `docus_medicalrecord`.`t_basic`
     *
     * @param tBasic 患者基础信息
     * @return 病案基础信息
     */
    List<TBasic> getBasicInfo(@Param("basic") TBasic tBasic);
}
