package com.docus.bgts.rpc.impl;

import cn.hutool.http.HttpUtil;
import com.alibaba.fastjson.JSON;
import com.docus.bgts.entity.CommonResult;
import com.docus.bgts.rpc.DownloadPlatformRpc;
import com.docus.bgts.rpc.dto.ReportDownDto;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import java.util.UUID;

/**
 * 下载平台 远程调用接口实现
 *
 * @author YongBin Wen
 * @date 2024/1/11 10:02
 */
@Service
@Slf4j
public class DownloadPlatformRpcImpl implements DownloadPlatformRpc {

    @Value("${docus.downloadPlatformAddress}")
    private String downloadPlatformAddress;

    @Override
    public CommonResult report(ReportDownDto resources) {
        String contextId = UUID.randomUUID().toString();
        String url = downloadPlatformAddress + "/api/downplatform/report";
        String bodyParam = JSON.toJSONString(resources);
        log.info("[{}] 上报病案文件到下载平台，地址：{} ，参数：{}", contextId, url, bodyParam);
        try {
            String resp = HttpUtil.post(url, bodyParam);
            log.info("[{}] 上报病案文件到下载平台，返回内容：{}", contextId, resp);
            return JSON.parseObject(resp, CommonResult.class);
        } catch (Exception ex) {
            log.error("[" + contextId + "] 上报病案文件到下载平台，出错啦！", ex);
            throw ex;
        }
    }

    @Override
    public CommonResult sealReport(ReportDownDto resources) {
        String contextId = UUID.randomUUID().toString();
        String url = downloadPlatformAddress + "/api/downplatform/sealReport";
        String bodyParam = JSON.toJSONString(resources);
        log.info("[{}] 上报封存病案文件到下载平台，地址：{} ，参数：{}", contextId, url, bodyParam);
        try {
            String resp = HttpUtil.post(url, bodyParam);
            log.info("[{}] 上报封存病案文件到下载平台，返回内容：{}", contextId, resp);
            return JSON.parseObject(resp, CommonResult.class);
        } catch (Exception ex) {
            log.error("[" + contextId + "] 上报封存病案文件到下载平台，出错啦！", ex);
            throw ex;
        }
    }
}
