package com.docus.bgts.service;

import com.docus.bgts.facade.IAfCollectTaskService;
import com.docus.bgts.facade.IMzSyncService;
import com.docus.bgts.mapper.dbmysql.AfCollectAddMapper;
import com.docus.bgts.utils.FileUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.util.CollectionUtils;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.util.Map;

/**
 * @author 曾文和
 * @description: 校验完整性业务
 * @createTime 2022/5/2 10:34
 */
@Service
public class CheckIntegrityService {
    private final Logger log = LoggerFactory.getLogger(getClass());
    @Autowired
    AfCollectAddMapper afCollectAddMapper;

    @Autowired
    IMzSyncService iMzSyncService;

    @Autowired
    IAfCollectTaskService afCollectTaskService;
    /**
     * 根据时间段检验完整性
     * @param startDate
     * @param endDate
     * @return
     */
    public boolean addSyncIntegrality(String startDate,String endDate) {
        //1
        //定义是否更新采集时间
        boolean flag = true;
        log.info("增量完整性同步开始");
        long startTime = System.currentTimeMillis();
        //获取分页数
        Integer pageSize = Integer.parseInt(String.valueOf(FileUtils.getJsonByName("pageSize")));
        List<String> jzhs;
        int front;
        for (int i = 0; ; i++) {
            front = i * pageSize;
            jzhs = afCollectAddMapper.listJzhAndAdd(front, pageSize, startDate,endDate);
            if (jzhs.size() == 0) {
                if(i == 0){
                    flag = false;
                }
                break;
            } else {
                //校验完整性
                addSyncIntegralityByJzhsMethod(jzhs);
            }
        }
        long endTime = System.currentTimeMillis();
        log.info("增量完整性同步结束,程序执行时间为：" + (endTime - startTime) + "毫秒");
        return flag;
    }

    /**
     * 校验完整性
     * @param jzhs
     */
    public void addSyncIntegralityByJzhsMethod(List<String> jzhs) {
        //处理完整性描述
        List<Map> maps = getCompleteInegruty(jzhs);
        //完整性检验写入
        integralityBySyncs(maps);
        log.info("本次成功同步数：" + maps.size());
    }

    /**
     * 处理完整性描述
     * @return
     */
    private List<Map> getCompleteInegruty(List<String> jzhs){
        //获取配置的校验完整性方式，1:根据af_collect_task完成情况 2:梅州根据信息科提供任务视图
        Integer checkIntegrityType = Integer.parseInt(String.valueOf(FileUtils.getJsonByName("checkIntegrityType")));
        if(null == checkIntegrityType){
            throw new RuntimeException("homeQualitySet文件中校验方式checkIntegrityType需要配置");
        }
        List<Map> maps = new ArrayList<>();
        if(checkIntegrityType == 1){
            //根据af_collect_task校验完整性
            maps = afCollectTaskService.getCompleteIntegrity(jzhs);
        }else if(checkIntegrityType == 2){
            //校验梅州完整性
            maps = iMzSyncService.getCompleteIntegrity(jzhs);
        }
        return maps;
    }

    /**
     * 完整性检验写入
     * @param maps {"jzh":记帐号,"file_title"：完整性描述}
     */
    private void integralityBySyncs(List<Map> maps) {
        StringBuilder sql;
        if (!CollectionUtils.isEmpty(maps)) {
            sql = new StringBuilder();
            for (Map map : maps) {
                sql.append("update docus_medicalrecord.t_basic set integrity_desc=");
                sql.append("'");
                sql.append(map.get("file_title"));
                sql.append("',update_time=now()");
                sql.append(" where jzh=");
                sql.append("'");
                sql.append(map.get("jzh"));
                sql.append("'");
                sql.append(";");
            }
            System.out.println(sql);
            afCollectAddMapper.dynamicSql(sql.toString());
        }
    }

    /**
     * 根据多个jzh逗号隔开的字符串校验完整性
     * @param jzhs
     */
    public void addSyncIntegralityByJzhs(String jzhs) {
        List<String> jzhList = Arrays.asList(jzhs.split(","));
        addSyncIntegralityByJzhsMethod(jzhList);
    }
}
